@@ -5,7 +5,7 @@ from collections import OrderedDict
 
 __all__ = ('dispatch', 'DispatchError')
 __author__ = 'Vladimir Keleshev <vladimir@keleshev.com>'
-__version__ = '0.0.1'
+__version__ = '0.0.2'
 __license__ = 'MIT'
 __keywords__ = 'docopt dispatch function adapter kwargs'
 __url__ = 'https://github.com/halst/docopt-dispatch'
@@ -20,22 +20,26 @@ class Dispatch(object):
     def __init__(self):
         self._functions = OrderedDict()
 
-    def on(self, argument):
+    def on(self, *patterns):
         def decorator(function):
-            self._functions[argument] = function
+            self._functions[patterns] = function
             return function
         return decorator
 
     def __call__(self, *args, **kwargs):
         from docopt import docopt
         arguments = docopt(*args, **kwargs)
-        for argument, function in self._functions.items():
-            if arguments[argument]:
+        for patterns, function in self._functions.items():
+            if all(arguments[pattern] for pattern in patterns):
                 function(**self._kwargify(arguments))
                 return
+        raise DispatchError('None of dispatch conditions %s is triggered'
+                            % self._formated_patterns)
 
-        raise DispatchError('None of dispatch conditions (%s) is triggered'
-                            % ', '.join(self._functions.keys()))
+    @property
+    def _formated_patterns(self):
+        return ', '.join(' '.join(pattern)
+                         for pattern in self._functions.keys())
 
     @staticmethod
     def _kwargify(arguments):
